==> wine-0.9.20.tar.bz2: wine-0.9.20/dlls/oledlg/resource.h <==
/*
 * Definitions for OLE dialog resources
 *
 * Copyright 2003 Ulrich Czekalla for CodeWeavers
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#define IDS_RESULTOBJDESC               101
#define IDS_RESULTFILEOBJDESC           102
#define IDS_BROWSE                      103
#define IDS_NOTOLEMOD                   104
#define IDS_NOTOLEMODCAPTION            105

#define UIINSERTOBJECT                  129

#define IDC_OBJTYPELIST                 1000
#define IDC_RESULT                      1001
#define IDC_CREATENEW                   1002
#define IDC_CREATECONTROL               1003
#define IDC_CREATEFROMFILE              1004
#define IDC_OBJTYPELBL                  1005
#define IDC_RESULTDESC                  1006
#define IDC_ADDCONTROL                  1007
#define IDC_ASICON                      1008
#define IDC_BROWSE                      1009
#define IDC_FILELBL                     1010
#define IDC_FILE                        1011

==> wine-1.1.17.tar.bz2: wine-1.1.17/dlls/oledlg/resource.h <==
/*
 * Definitions for OLE dialog resources
 *
 * Copyright 2003 Ulrich Czekalla for CodeWeavers
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#define IDS_RESULTOBJDESC               101
#define IDS_RESULTFILEOBJDESC           102
#define IDS_BROWSE                      103
#define IDS_NOTOLEMOD                   104
#define IDS_NOTOLEMODCAPTION            105

#define UIINSERTOBJECT                  129

#define IDC_OBJTYPELIST                 1000
#define IDC_RESULT                      1001
#define IDC_CREATENEW                   1002
#define IDC_CREATECONTROL               1003
#define IDC_CREATEFROMFILE              1004
#define IDC_OBJTYPELBL                  1005
#define IDC_RESULTDESC                  1006
#define IDC_ADDCONTROL                  1007
#define IDC_ASICON                      1008
#define IDC_BROWSE                      1009
#define IDC_FILELBL                     1010
#define IDC_FILE                        1011

/* String ids for Paste Special */
#define IDS_PS_PASTE_DATA                 0x190
#define IDS_PS_PASTE_OBJECT               0x191
#define IDS_PS_PASTE_OBJECT_AS_ICON       0x192
#define IDS_PS_PASTE_LINK_DATA            0x193
#define IDS_PS_PASTE_LINK_OBJECT          0x194
#define IDS_PS_PASTE_LINK_OBJECT_AS_ICON  0x195
#define IDS_PS_NON_OLE                    0x196
#define IDS_PS_UNKNOWN_TYPE               0x197
#define IDS_PS_UNKNOWN_SRC                0x198
#define IDS_PS_UNKNOWN_APP                0x199
